Struct
QmiMessageLocInjectUtcTimeInput
since: 1.37
Description [src]
struct QmiMessageLocInjectUtcTimeInput {
/* No available fields */
}
The QmiMessageLocInjectUtcTimeInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Constructors
qmi_message_loc_inject_utc_time_input_new
Allocates a new QmiMessageLocInjectUtcTimeInput.
since: 1.37
Instance methods
qmi_message_loc_inject_utc_time_input_get_time_source
Get the ‘Time Source’ field from self.
since: 1.37
qmi_message_loc_inject_utc_time_input_get_time_uncertainty
Get the ‘Time Uncertainty’ field from self.
since: 1.37
qmi_message_loc_inject_utc_time_input_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_loc_inject_utc_time_input_set_time_source
Set the ‘Time Source’ field in the message.
since: 1.37
qmi_message_loc_inject_utc_time_input_set_time_uncertainty
Set the ‘Time Uncertainty’ field in the message.
since: 1.37
qmi_message_loc_inject_utc_time_input_set_utc_time
Set the ‘UTC Time’ field in the message.
since: 1.37
qmi_message_loc_inject_utc_time_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37